===============
cynet
===============

.. figure:: https://img.shields.io/pypi/dm/qbiome.svg
   :alt: cynet PyPI Downloads
.. figure:: https://img.shields.io/pypi/v/qbiome.svg
   :alt: cynet version

.. image:: http://zed.uchicago.edu/logo/logozed1.png
   :height: 400px
   :scale: 50 %
   :alt: alternate text
   :align: center


.. class:: no-web no-pdf

:Info: Draft link will be posted here
:Author: ZeD@UChicago <zed.uchicago.edu>
:Description: Application of quasinets (https://pypi.org/project/quasinet/) for microbiome analysis  for learning rules of organization, maturation, competition and succession in microbiome ecosystems. 
:Documentation: https://zeroknowledgediscovery.github.io/qbiome/qbiome/index.html
